@@ -333,8 +333,8 @@ getMetaPrograms <- function(nmf.res,
   #Remove any empty meta-program
   if (remove.empty) {
     keep <- metaprograms.metrics$numberGenes > 0
-    metaprograms.metrics <- metaprograms.metrics[keep,]
-    metaprograms.composition <- metaprograms.composition[keep,]
+    metaprograms.metrics <- metaprograms.metrics[keep, ,drop=F]
+    metaprograms.composition <- metaprograms.composition[keep, ,drop=F]
     markers.consensus <- markers.consensus[keep]
     if (sum(!keep)>0) {
       message(sprintf("Dropped %i empty meta-programs", sum(!keep)))
@@ -352,9 +352,9 @@ getMetaPrograms <- function(nmf.res,
   names(markers.consensus) <- new.names
   
   #Reorder metrics and composition tables
-  metaprograms.metrics <- metaprograms.metrics[ord,]
+  metaprograms.metrics <- metaprograms.metrics[ord,,drop=F]
   rownames(metaprograms.metrics) <- new.names
-  metaprograms.composition <- metaprograms.composition[ord,]
+  metaprograms.composition <- metaprograms.composition[ord,,drop=F]
   rownames(metaprograms.composition) <- new.names
   
   map.index <- seq_along(old.names)
@@ -408,6 +408,8 @@ getMetaPrograms <- function(nmf.res,
 #' 
 #' @importFrom pheatmap pheatmap
 #' @importFrom viridis viridis
+#' @importFrom colorspace hex
+#' @importFrom methods is
 #' @importFrom stats as.dendrogram
 #' @export  
 plotMetaPrograms <- function(mp.res,
@@ -464,6 +466,22 @@ plotMetaPrograms <- function(mp.res,
     tree <- FALSE
   }
   
+  #custom annotation colors
+  if (is.null(annotation_colors)){
+    annotation_colors_use <- annotation_colors
+  }
+  else if (!is(annotation_colors, "list")){
+    if(is(annotation_colors, "character") & length(annotation_colors)>=nMP){
+      annotation_colors <- annotation_colors[seq(1, nMP)]
+      annotation_colors_use <- list(Metaprogram=annotation_colors)
+    } 
+  }
+  else if (any("Metaprogram" %in% names(annotation_colors))){
+    annotation_colors_use <- annotation_colors
+  } else {
+    stop("annotation_colors should be a character vector having same length with nMP!")
+  }
+  
   ph <- pheatmap(J,
                  scale = scale,
                  color = palette,
@@ -476,7 +494,7 @@ plotMetaPrograms <- function(mp.res,
                  gaps_col = gaps,
                  annotation_col = annotation_col,
                  annotation_row = annotation_col,
-                 annotation_colors = annotation_colors,
+                 annotation_colors = annotation_colors_use,
                  annotation_names_col = FALSE,
                  annotation_names_row = FALSE,
                  show_rownames = show_rownames,
@@ -494,8 +512,8 @@ plotMetaPrograms <- function(mp.res,
 #'
 #' @param genes A vector of genes
 #' @param universe Background universe of gene symbols (passed on to \code{fgsea::fora})
-#' @param category GSEA main category (e.g. "H" or "C5")
-#' @param subcategory GSEA subcategory
+#' @param category GSEA main category/collection (e.g. "H" or "C5")
+#' @param subcategory GSEA subcategory/subcollection
 #' @param species Species for GSEA analysis. For a list of the available species,
 #'     type \code{msigdbr::msigdbr_species()}
 #' @param custom.db A custom database of signatures, to be used instead of MSigDB. 
@@ -505,6 +523,7 @@ plotMetaPrograms <- function(mp.res,
 #' @return Returns a table of enriched gene programs from GSEA
 #'
 #' @examples
+#' \donttest{
 #' data(sampleObj)
 #' geneset <- c("BANK1","CD22","CD79A","CD19","IGHD","IGHG3","IGHM")
 #' #test is conditional on availability of suggested packages
@@ -514,7 +533,7 @@ plotMetaPrograms <- function(mp.res,
 #'        universe=rownames(sampleObj),
 #'        category = "C8")
 #' }
-#' 
+#' }
 #' @export  
 runGSEA <- function(genes, universe=NULL,
                     category="H", subcategory=NULL,
@@ -539,7 +558,8 @@ runGSEA <- function(genes, universe=NULL,
       stop("custom.db should be a named list", call. = FALSE)
     DB_list <- custom.db
   } else {  # use signatures from mSigDB
-    msig_df <- msigdbr::msigdbr(species = species, category = category, subcategory=subcategory)
+    msig_df <- msigdbr::msigdbr(species = species, collection = category,
+                                subcollection=subcategory)
     DB_list <- split(x=msig_df$gene_symbol, f=msig_df$gs_name)
   }
   
@@ -705,7 +725,7 @@ findVariableFeatures_wfilters <- function(
   
   varfeat <- setdiff(varfeat, genes.block)
   #Also remove genes that are very poorly or always expressed
-  means <- apply(GetAssayData(obj, assay=assay, slot="data")[varfeat,], 1, mean)
+  means <- apply(GetAssayData(obj, assay=assay, layer="data")[varfeat,], 1, mean)
   removeGenes2 <- names(means[means<min.exp | means>max.exp])
   
   varfeat <- setdiff(varfeat, removeGenes2)
